# Implementation of a deck of cards.
# by CSCI 111

from card import *
from random import shuffle

class Deck:
    """ A class to represent a deck of playing cards."""
    
    def __init__(self):
        """Creates a new Deck object, filled with one of each
        unique card."""
        
        self.listOfCards = []
        for suit in ["clubs","hearts","diamonds","spades"]:
            for rank in range(2,15):
                self.listOfCards.append(Card(rank, suit))

    def __str__(self):
        """Returns a string representing the cards that are
        in the deck."""
        
        deckRep= ""
        for c in self.listOfCards:
            deckRep += str(c) + "\n"
        return deckRep

    def numRemaining(self):
        """Returns the number of cards left in the deck."""
        return len(self.listOfCards)
        
    def shuffle(self):
        "Shuffles the deck of cards."
        shuffle(self.listOfCards)
        
    def drawCard(self):
        "Draws a card from the top of the deck."
        return self.listOfCards.pop(0)
        
    def drawCards(self, numCards=1):
        """Returns a list of cards, drawn from the top of the deck,
        assuming there are enough cards left."""
        cardsDrawn = []
        for x in range(numCards):
            card = self.listOfCards.pop(0)
            cardsDrawn.append(card)
        return cardsDrawn
            
        
    # Other functionality possibilities:     
    # cut 
    # drawCard with multiple cards
    # put cards back into the deck
    # start the deck over
    # deal cards based on the number of players
    # view (but don't remove) the top 
    
        
def main():
    d = Deck()
    print(d)
    print("The number of cards remaining in the deck is", d.numRemaining())
    
    d.shuffle()
    print("Shuffled deck:")
    print(d)
    
    print("Drew card:", d.drawCard())
    print("The number of cards remaining in the deck is", d.numRemaining())
    
# Since I am probably going to import this script into another script,
# I only want to call main() when it's *not* imported
if __name__ == "__main__":
    main()
