class Card:
    """
    A class to represent a standard playing card. The ranks are ints:
    2-10 for numbered cards, 11=Jack, 12=Queen, 13=King, 14=Ace.
    The suits are strings: 'clubs', 'spades', 'hearts', 'diamonds'.
    """
    
    def __init__(self, rank, suit):
        "Constructs a new Card object with the given rank (an int) and suit (a string)."
        self.rank = rank
        self.suit = suit

    def __str__(self):
        "Returns a string describing the card as 'rank of suit'."
        result = ""
        if self.rank == 11:
            result += "Jack"
        elif self.rank == 12:
            result += "Queen"
        elif self.rank == 13:
            result += "King"
        elif self.rank == 14:
            result += "Ace"
        else:
            result += str(self.rank)
        result += " of " + self.suit
        return result
        
    def getRank(self):
        "Returns rank."	
        return self.rank

    def getSuit(self):
        "Returns suit."
        return self.suit
        
    def rummyValue(self):
        "Returns the card's rummy value"
        if self.getRank() < 10: # handles number cards
            return 5
        elif self.rank == 14: # handles Ace
            return 15
        else: # handles 10 and face cards
            return 10
            
    def __eq__(self, other):
        """Returns true if this object and other are equivalent
        based on ..."""
        
        # verify that self and other are the same type
        if type(self) != type(other):
            return False
        # do comparison
        return self.rank == other.rank and self.suit == other.suit
        
    def __lt__(self, other):
        """ Compares Card objects by """
        
        # verify that self and other are the same type
        
        # do comparison
        return self.rank < other.rank

def totalOrderCardKeyFunction(card):
    """Returns the key to be used for comparison.
    Parameter: card of type Card
    """
    
    # creates a string out of the attributes of the Card that is used to compare
    # the Cards.  
    
    # This key means that the cards will be ordered by their
    # rank and then their suit.
    
    #key = "%2d %s" % (card.getRank(), card.getSuit())
    
    # This key means that cards will be ordered by their suit
    # then their rank
    key = "%s %2d" % (card.getSuit(), card.getRank())
    
    # Is one way to sort better than the other?
    
    return key
    
def main():
    cards = []
    
    for suit in ["clubs","hearts","diamonds","spades"]:
        for rank in range(2,15):
            cards.append(Card(rank, suit))

    # sort the cards using the key specified by the function
    cards.sort(key=totalOrderCardKeyFunction)
    
    print("The ordered cards are: ")
    for c in cards:
        print(c)
    
    
# Since I am probably going to import this script into another script,
# I only want to call main() when it's *not* imported 
if __name__ == '__main__':
    main()
